@@ -27,8 +27,12 @@
 
 #include <LXQt/ConfigDialog>
 #ifdef Q_OS_LINUX
+#ifdef NO_SYSTEMD
+#include "nosdtimedatectl.h"
+#else
 #include "dbustimedatectl.h"
 #endif
+#endif
 #ifdef Q_OS_FREEBSD
 #include "fbsdtimedatectl.h"
 #endif
@@ -54,8 +58,12 @@ private:
 
 private:
 #ifdef Q_OS_LINUX
+#ifdef NO_SYSTEMD
+    NOSDTimeDateCtl mTimeDateCtl;
+#else
     DbusTimeDateCtl mTimeDateCtl;
 #endif
+#endif
 #ifdef Q_OS_FREEBSD
     FBSDTimeDateCtl mTimeDateCtl;
 #endif
